@@ -124,8 +124,8 @@ def add_template(db,name,src_path,dest_path,created=None):
         db,
         name,
         created,
-        str(src_path),
-        str(dest_path)
+        str(src_path.absolute()),
+        str(dest_path.absolute())
         )
 
 def del_template(db,name):
@@ -152,8 +152,8 @@ def update_template(db,name,src_path,dest_path):
         db,
         name,
         created,
-        str(src_path),
-        str(dest_path)
+        str(src_path.absolute()),
+        str(dest_path.absolute())
         )
 
 def clone_template(db,name,path="."):
